# Release History

## 1.0.5 (09/13/2022)

- Update documentation

## 1.0.4 (08/17/2022)

- Improvements around tests and code coverage

## 1.0.3 (08/08/2022)

- Official Documentation site

## 1.0.2 (08/05/2022)

- Standardized documentation

- Test suite

## 1.0.1 (08/04/2022)

- Naming conventions bug fix

## 1.0.0 (08/02/2022)

- Initial Release

- Configured, CHANGELOG, LICENSE, and MANIFEST

- Connect to a samba server remotely

- Connect via hostname, port, username and password

- Download, upload, delete, and move files on the samba server
